@@ -3,7 +3,7 @@ import json
 from django.http import HttpResponse
 from django.conf import settings
 import os
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.module_loading import import_string
 
 
